# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ayab/ayab_gui.ui'
#
# Created: Mon Feb  9 22:25:25 2015
#      by: PyQt4 UI code generator 4.10.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName(_fromUtf8("MainWindow"))
        MainWindow.resize(1008, 856)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName(_fromUtf8("centralwidget"))
        self.gridLayout = QtGui.QGridLayout(self.centralwidget)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.assistant_dock = QtGui.QScrollArea(self.centralwidget)
        self.assistant_dock.setEnabled(True)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.assistant_dock.sizePolicy().hasHeightForWidth())
        self.assistant_dock.setSizePolicy(sizePolicy)
        self.assistant_dock.setMinimumSize(QtCore.QSize(280, 0))
        self.assistant_dock.setMaximumSize(QtCore.QSize(540, 16777215))
        self.assistant_dock.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.assistant_dock.setFrameShadow(QtGui.QFrame.Plain)
        self.assistant_dock.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.assistant_dock.setWidgetResizable(False)
        self.assistant_dock.setObjectName(_fromUtf8("assistant_dock"))
        self.dockWidgetContents = QtGui.QWidget()
        self.dockWidgetContents.setGeometry(QtCore.QRect(0, 0, 500, 700))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dockWidgetContents.sizePolicy().hasHeightForWidth())
        self.dockWidgetContents.setSizePolicy(sizePolicy)
        self.dockWidgetContents.setObjectName(_fromUtf8("dockWidgetContents"))
        self.verticalLayout_5 = QtGui.QVBoxLayout(self.dockWidgetContents)
        self.verticalLayout_5.setSizeConstraint(QtGui.QLayout.SetFixedSize)
        self.verticalLayout_5.setObjectName(_fromUtf8("verticalLayout_5"))
        self.widget_imgload = QtGui.QWidget(self.dockWidgetContents)
        self.widget_imgload.setEnabled(True)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.widget_imgload.sizePolicy().hasHeightForWidth())
        self.widget_imgload.setSizePolicy(sizePolicy)
        self.widget_imgload.setObjectName(_fromUtf8("widget_imgload"))
        self.verticalLayout = QtGui.QVBoxLayout(self.widget_imgload)
        self.verticalLayout.setSizeConstraint(QtGui.QLayout.SetMaximumSize)
        self.verticalLayout.setMargin(0)
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.label_3 = QtGui.QLabel(self.widget_imgload)
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.verticalLayout.addWidget(self.label_3)
        self.module_dropdown = QtGui.QComboBox(self.widget_imgload)
        self.module_dropdown.setObjectName(_fromUtf8("module_dropdown"))
        self.verticalLayout.addWidget(self.module_dropdown)
        self.filename_lineedit = QtGui.QLineEdit(self.widget_imgload)
        self.filename_lineedit.setEnabled(False)
        self.filename_lineedit.setText(_fromUtf8(""))
        self.filename_lineedit.setObjectName(_fromUtf8("filename_lineedit"))
        self.verticalLayout.addWidget(self.filename_lineedit)
        self.load_file_button = QtGui.QPushButton(self.widget_imgload)
        self.load_file_button.setObjectName(_fromUtf8("load_file_button"))
        self.verticalLayout.addWidget(self.load_file_button)
        self.verticalLayout_5.addWidget(self.widget_imgload)
        self.widget_optionsdock = QtGui.QWidget(self.dockWidgetContents)
        self.widget_optionsdock.setEnabled(False)
        self.widget_optionsdock.setObjectName(_fromUtf8("widget_optionsdock"))
        self.verticalLayout_2 = QtGui.QVBoxLayout(self.widget_optionsdock)
        self.verticalLayout_2.setSizeConstraint(QtGui.QLayout.SetMaximumSize)
        self.verticalLayout_2.setMargin(0)
        self.verticalLayout_2.setObjectName(_fromUtf8("verticalLayout_2"))
        self.line = QtGui.QFrame(self.widget_optionsdock)
        self.line.setFrameShape(QtGui.QFrame.HLine)
        self.line.setFrameShadow(QtGui.QFrame.Sunken)
        self.line.setObjectName(_fromUtf8("line"))
        self.verticalLayout_2.addWidget(self.line)
        self.knitting_options_dock = QtGui.QDockWidget(self.widget_optionsdock)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.knitting_options_dock.sizePolicy().hasHeightForWidth())
        self.knitting_options_dock.setSizePolicy(sizePolicy)
        self.knitting_options_dock.setObjectName(_fromUtf8("knitting_options_dock"))
        self.dockWidgetContents_2 = QtGui.QWidget()
        self.dockWidgetContents_2.setObjectName(_fromUtf8("dockWidgetContents_2"))
        self.knitting_options_dock.setWidget(self.dockWidgetContents_2)
        self.verticalLayout_2.addWidget(self.knitting_options_dock)
        self.verticalLayout_5.addWidget(self.widget_optionsdock)
        self.line_2 = QtGui.QFrame(self.dockWidgetContents)
        self.line_2.setFrameShape(QtGui.QFrame.HLine)
        self.line_2.setFrameShadow(QtGui.QFrame.Sunken)
        self.line_2.setObjectName(_fromUtf8("line_2"))
        self.verticalLayout_5.addWidget(self.line_2)
        self.widget_knitcontrol = QtGui.QWidget(self.dockWidgetContents)
        self.widget_knitcontrol.setEnabled(True)
        self.widget_knitcontrol.setObjectName(_fromUtf8("widget_knitcontrol"))
        self.verticalLayout_3 = QtGui.QVBoxLayout(self.widget_knitcontrol)
        self.verticalLayout_3.setSizeConstraint(QtGui.QLayout.SetMaximumSize)
        self.verticalLayout_3.setMargin(0)
        self.verticalLayout_3.setObjectName(_fromUtf8("verticalLayout_3"))
        self.knit_button = QtGui.QPushButton(self.widget_knitcontrol)
        self.knit_button.setEnabled(False)
        self.knit_button.setObjectName(_fromUtf8("knit_button"))
        self.verticalLayout_3.addWidget(self.knit_button)
        self.cancel_button = QtGui.QPushButton(self.widget_knitcontrol)
        self.cancel_button.setEnabled(False)
        self.cancel_button.setObjectName(_fromUtf8("cancel_button"))
        self.verticalLayout_3.addWidget(self.cancel_button)
        self.verticalLayout_5.addWidget(self.widget_knitcontrol)
        self.assistant_dock.setWidget(self.dockWidgetContents)
        self.gridLayout.addWidget(self.assistant_dock, 0, 1, 3, 1)
        self.image_side_panel = QtGui.QVBoxLayout()
        self.image_side_panel.setObjectName(_fromUtf8("image_side_panel"))
        self.widget_6 = QtGui.QWidget(self.centralwidget)
        self.widget_6.setObjectName(_fromUtf8("widget_6"))
        self.horizontalLayout_2 = QtGui.QHBoxLayout(self.widget_6)
        self.horizontalLayout_2.setMargin(0)
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        self.label_4 = QtGui.QLabel(self.widget_6)
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.horizontalLayout_2.addWidget(self.label_4)
        self.dimensions_label = QtGui.QLabel(self.widget_6)
        self.dimensions_label.setText(_fromUtf8(""))
        self.dimensions_label.setObjectName(_fromUtf8("dimensions_label"))
        self.horizontalLayout_2.addWidget(self.dimensions_label)
        self.image_side_panel.addWidget(self.widget_6)
        self.image_pattern_view = QtGui.QGraphicsView(self.centralwidget)
        self.image_pattern_view.setObjectName(_fromUtf8("image_pattern_view"))
        self.image_side_panel.addWidget(self.image_pattern_view)
        self.progress_label = QtGui.QLabel(self.centralwidget)
        self.progress_label.setText(_fromUtf8(""))
        self.progress_label.setAlignment(QtCore.Qt.AlignCenter)
        self.progress_label.setObjectName(_fromUtf8("progress_label"))
        self.image_side_panel.addWidget(self.progress_label)
        self.progressBar = QtGui.QProgressBar(self.centralwidget)
        self.progressBar.setProperty("value", 0)
        self.progressBar.setObjectName(_fromUtf8("progressBar"))
        self.image_side_panel.addWidget(self.progressBar)
        self.gridLayout.addLayout(self.image_side_panel, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1008, 25))
        self.menubar.setObjectName(_fromUtf8("menubar"))
        self.menuFile = QtGui.QMenu(self.menubar)
        self.menuFile.setObjectName(_fromUtf8("menuFile"))
        self.menuHelp = QtGui.QMenu(self.menubar)
        self.menuHelp.setObjectName(_fromUtf8("menuHelp"))
        self.menuTools = QtGui.QMenu(self.menubar)
        self.menuTools.setObjectName(_fromUtf8("menuTools"))
        self.menuImage_Actions = QtGui.QMenu(self.menubar)
        self.menuImage_Actions.setEnabled(False)
        self.menuImage_Actions.setObjectName(_fromUtf8("menuImage_Actions"))
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName(_fromUtf8("statusbar"))
        MainWindow.setStatusBar(self.statusbar)
        self.actionLoad_AYAB_Firmware = QtGui.QAction(MainWindow)
        self.actionLoad_AYAB_Firmware.setObjectName(_fromUtf8("actionLoad_AYAB_Firmware"))
        self.actionQuit = QtGui.QAction(MainWindow)
        self.actionQuit.setObjectName(_fromUtf8("actionQuit"))
        self.actionOpen_Knitting_Project = QtGui.QAction(MainWindow)
        self.actionOpen_Knitting_Project.setObjectName(_fromUtf8("actionOpen_Knitting_Project"))
        self.actionAbout = QtGui.QAction(MainWindow)
        self.actionAbout.setObjectName(_fromUtf8("actionAbout"))
        self.actionHelp = QtGui.QAction(MainWindow)
        self.actionHelp.setObjectName(_fromUtf8("actionHelp"))
        self.actionInvert = QtGui.QAction(MainWindow)
        self.actionInvert.setObjectName(_fromUtf8("actionInvert"))
        self.actionMirror = QtGui.QAction(MainWindow)
        self.actionMirror.setObjectName(_fromUtf8("actionMirror"))
        self.actionRotate_Left = QtGui.QAction(MainWindow)
        self.actionRotate_Left.setObjectName(_fromUtf8("actionRotate_Left"))
        self.actionRotate_Right = QtGui.QAction(MainWindow)
        self.actionRotate_Right.setObjectName(_fromUtf8("actionRotate_Right"))
        self.actionSmart_Resize = QtGui.QAction(MainWindow)
        self.actionSmart_Resize.setObjectName(_fromUtf8("actionSmart_Resize"))
        self.actionVertical_Flip = QtGui.QAction(MainWindow)
        self.actionVertical_Flip.setObjectName(_fromUtf8("actionVertical_Flip"))
        self.menuFile.addAction(self.actionQuit)
        self.menuHelp.addAction(self.actionAbout)
        self.menuTools.addAction(self.actionLoad_AYAB_Firmware)
        self.menuImage_Actions.addAction(self.actionInvert)
        self.menuImage_Actions.addSeparator()
        self.menuImage_Actions.addAction(self.actionVertical_Flip)
        self.menuImage_Actions.addAction(self.actionMirror)
        self.menuImage_Actions.addSeparator()
        self.menuImage_Actions.addAction(self.actionRotate_Left)
        self.menuImage_Actions.addAction(self.actionRotate_Right)
        self.menuImage_Actions.addSeparator()
        self.menuImage_Actions.addAction(self.actionSmart_Resize)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuImage_Actions.menuAction())
        self.menubar.addAction(self.menuTools.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(_translate("MainWindow", "All Yarns Are Beautiful", None))
        self.assistant_dock.setWindowTitle(_translate("MainWindow", "Asistant", None))
        self.label_3.setText(_translate("MainWindow", "Load Images and Mode", None))
        self.load_file_button.setText(_translate("MainWindow", "1. Load Image File", None))
        self.knitting_options_dock.setWindowTitle(_translate("MainWindow", "Knitting Options", None))
        self.knit_button.setText(_translate("MainWindow", "3. Knit!", None))
        self.cancel_button.setText(_translate("MainWindow", "Cancel Knitting", None))
        self.label_4.setText(_translate("MainWindow", "Image Dimensions", None))
        self.menuFile.setTitle(_translate("MainWindow", "File", None))
        self.menuHelp.setTitle(_translate("MainWindow", "Help", None))
        self.menuTools.setTitle(_translate("MainWindow", "Tools", None))
        self.menuImage_Actions.setTitle(_translate("MainWindow", "Image Actions", None))
        self.actionLoad_AYAB_Firmware.setText(_translate("MainWindow", "Load AYAB Firmware", None))
        self.actionQuit.setText(_translate("MainWindow", "Quit", None))
        self.actionOpen_Knitting_Project.setText(_translate("MainWindow", "Open Knitting Project", None))
        self.actionAbout.setText(_translate("MainWindow", "Help - About", None))
        self.actionHelp.setText(_translate("MainWindow", "Help", None))
        self.actionInvert.setText(_translate("MainWindow", "Invert", None))
        self.actionMirror.setText(_translate("MainWindow", "Mirror", None))
        self.actionRotate_Left.setText(_translate("MainWindow", "Rotate Left", None))
        self.actionRotate_Right.setText(_translate("MainWindow", "Rotate Right", None))
        self.actionSmart_Resize.setText(_translate("MainWindow", "Smart Resize", None))
        self.actionVertical_Flip.setText(_translate("MainWindow", "Vertical Flip", None))

